@@ -48,7 +48,8 @@ def includeme(config):
     j2_env = config.get_jinja2_environment()
     j2_env.filters['urlencode'] = url_quote
     config.add_static_view('_debug_toolbar/static', STATIC_PATH)
-    config.add_tween('pyramid_debugtoolbar.toolbar.toolbar_tween_factory')
+    config.add_tween('pyramid_debugtoolbar.toolbar.toolbar_tween_factory',
+                     alias='pdbt')
     config.add_subscriber(
         'pyramid_debugtoolbar.toolbar.beforerender_subscriber',
         'pyramid.events.BeforeRender')
